import { DeepClientInstance, SerialOperation } from '@deep-foundation/deeplinks/imports/client.js';
import { Package } from './package';
import { ClearWatchOptions, Position, PositionOptions } from '@capacitor/geolocation';
import { GeolocationPlugin } from '@capacitor/geolocation';
/**
 *
 * @example
 * #### Create a decorator from another decorator
```ts
const deep = new DeepClient({token: ''});
const anotherDeepDecorator = createAnotherDecorator(deep); // Note that this step is optional and showed only to demonstrate that you can create a decorator from another decorator and have a chain of decorators
const geolocationDeepDecorator = createAdditionalFeatureDecorator(anotherDeepDecorator);
```
 */
export declare function createGeolocationDecorator<TDeepClient extends DeepClientInstance>(deep: TDeepClient): TDeepClient & {
    "@deep-foundation/capacitor-geolocation": Package;
    capacitorGeolocationPackage: Package;
    requiredPackagesInMinilinksToApply: string[];
    applyRequiredPackagesInMinilinks(): Promise<{
        errors?: import("@deep-foundation/deeplinks/imports/minilinks").MinilinkError[] | undefined;
        anomalies?: import("@deep-foundation/deeplinks/imports/minilinks").MinilinkError[] | undefined;
    }>;
    insertPosition(options: InsertPositionOptions): Promise<import("@deep-foundation/deeplinks/imports/client.js").DeepClientResult<{
        id: any;
    }[]>>;
    makePositionInsertOperations(options: MakePositionInsertOperationsOptions): MakePositionInsertOperationsResult;
    updatePosition(options: UpdatePositionOptions): Promise<import("@deep-foundation/deeplinks/imports/client.js").DeepClientResult<{
        id: any;
    }[]>>;
    makeUpdatePositionOperations(options: MakeUpdateUpdatePositionOperationsOptions): MakeUpdateUpdatePositionOperationsResult;
    getPosition(options: GetPositionOptions): GetPositionResult;
    watchPosition(options: WatchPositionOptions): Promise<string>;
    clearWatch(options: ClearWatchOptions): Promise<void>;
    checkPermissions(): Promise<import("@capacitor/geolocation").PermissionStatus>;
    requestPermissions(): Promise<import("@capacitor/geolocation").PermissionStatus>;
};
export type GeolocationDecorator<TDeepClient extends DeepClientInstance = DeepClientInstance> = TDeepClient & {
    capacitorGeolocationPackage: Package;
    requiredPackagesInMinilinksToApply: Array<string>;
    applyRequiredPackagesInMinilinks(): ReturnType<DeepClientInstance['minilinks']['apply']>;
    insertPosition(options: InsertPositionOptions): InsertPositionResult;
    updatePosition(options: UpdatePositionOptions): UpdatePositionResult;
    makeUpdatePositionOperations(options: MakeUpdateUpdatePositionOperationsOptions): MakeUpdateUpdatePositionOperationsResult;
    makePositionInsertOperations(options: MakePositionInsertOperationsOptions): MakePositionInsertOperationsResult;
    getPosition(options: GetPositionOptions): GetPositionResult;
    watchPosition(options: WatchPositionOptions): WatchPositionResult;
    clearWatch(options: ClearWatchOptions): ReturnType<GeolocationPlugin['clearWatch']>;
    checkPermissions(): CheckPermissionsResult;
    requestPermissions(): RequestPermissionsResult;
};
export type InsertPositionOptions = {
    position: Position | null;
    containerLinkId?: number;
    id?: number;
};
export type InsertPositionResult = ReturnType<DeepClientInstance['serial']>;
export type MakePositionInsertOperationsOptions = {
    position: Position | null;
    containerLinkId?: number;
    id?: number;
};
export type MakePositionInsertOperationsResult = Promise<Array<SerialOperation>>;
export type GetPositionOptions = {
    linkId: number;
};
export type GetPositionResult = Promise<Partial<Position> | undefined>;
export type WatchPositionOptions = {
    watchPositionOptions: PositionOptions;
    containerLinkId?: number;
};
export type WatchPositionResult = ReturnType<GeolocationPlugin['watchPosition']>;
export type UpdatePositionOptions = {
    position: Position | null;
    id: number;
};
export type UpdatePositionResult = ReturnType<DeepClientInstance['serial']>;
export type MakeUpdateUpdatePositionOperationsOptions = {
    position: Position | null;
    id: number;
};
export type MakeUpdateUpdatePositionOperationsResult = Promise<Array<SerialOperation>>;
export type CheckPermissionsResult = ReturnType<GeolocationPlugin['checkPermissions']>;
export type RequestPermissionsResult = ReturnType<GeolocationPlugin['requestPermissions']>;
